ObservabilityModel class

Constructors

ObservabilityModel(String? observeMessage, String? logGroup)

Properties

formattedDate String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loggroup String?
getter/setter pair
logstream String?
getter/setter pair
message String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printRequest(String url) String
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited